@@ -82,7 +82,10 @@ class AclClient(object):
         endpoint = "api/ipv{}/acl/{}/24".format(self.ip_version, self.get_ip_vlan(environment))
         response = self._make_request(http_verb="PUT", endpoint=endpoint, payload= json.dumps(payload))
 
-        return json.loads(response.data)
+        json_data = json.loads(response.data)
+        LOG.debug("JSON request.DATA decoded: {}".format(json_data))
+
+        return json_data
 
     def revoke_acl_for(self, environment, vlan, payload):
         LOG.info("REVOKE ACLs for {} on {}".format(vlan, environment))
@@ -91,7 +94,10 @@ class AclClient(object):
         endpoint = "api/ipv{}/acl/{}/24".format(self.ip_version, self.get_ip_vlan(environment))
         response = self._make_request(http_verb="PURGE", endpoint=endpoint, payload= payload)
 
-        return json.loads(response.data)
+        json_data = json.loads(response.data)
+        LOG.debug("JSON request.DATA decoded: {}".format(json_data))
+
+        return json_data
 
     def list_jobs(self):
         LOG.info("Retrieving Jobs list.")
